==> geant4.10.05.tar.gz: geant4.10.05/source/processes/electromagnetic/dna/utils/src/G4VDNAReactionModel.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
#include "G4VDNAReactionModel.hh"

G4VDNAReactionModel::G4VDNAReactionModel()
{
  fReactionTable = 0;
}

G4VDNAReactionModel::G4VDNAReactionModel(const G4VDNAReactionModel& right)
{
  fReactionTable = right.fReactionTable;
}

G4VDNAReactionModel::~G4VDNAReactionModel()
{
  fReactionTable = 0;
}

G4VDNAReactionModel& G4VDNAReactionModel::operator=(const G4VDNAReactionModel& right)
{
  if (this == &right) return *this;
  fReactionTable = right.fReactionTable;
  return *this;
}

==> geant4.10.06.p03.tar.gz: geant4.10.06.p03/source/processes/electromagnetic/dna/utils/src/G4VDNAReactionModel.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
#include "G4VDNAReactionModel.hh"

G4VDNAReactionModel::G4VDNAReactionModel()
    : fpReactionTable(nullptr)
{
}

G4VDNAReactionModel::~G4VDNAReactionModel() = default;

void G4VDNAReactionModel::SetReactionTable(const G4DNAMolecularReactionTable* pReactionTable)
{
    fpReactionTable = pReactionTable;
}

const G4DNAMolecularReactionTable* G4VDNAReactionModel::GetReactionTable()
{
    return fpReactionTable;
}
